@@ -12,7 +12,7 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     buttonsVisible = true;
     vector = new QVector<ButtonWidget*>;
     bgPath = QString::fromUtf8("/home/user/.qtirreco/themes/default/bg/qtirreco/irreco_logo.png");
-    socket = new LircSocket(this);
+    socket = new Socket(this);
     timer = new QTimer(this);
     timer2 = new QTimer(this);
     timer2Index = 0;
@@ -22,12 +22,15 @@ LayoutWidget::LayoutWidget(QMainWindow *parent ) : QWidget( parent )
     timeout = 1000;
     timer->setInterval(timeout);
     timer2->setInterval(timeout2);
-    socket->openSocket(LIRCD);
+    socket->create();
+    bool connected = socket->connect("localhost", 8765);
+    if(!connected) QMessageBox::warning(this,"Socket connection","Socket connection failed!");
 }
 
 LayoutWidget::~LayoutWidget()
 {
-    socket->closeSocket();
+    //socket->closeSocket();
+
 }
 void LayoutWidget::setUseModeEnabled(bool useMode)
 {
@@ -469,8 +472,13 @@ void LayoutWidget::sendIrCommands(QStringList commands)
       //  socket->openSocket(LIRCD);
         const QString command = "SEND_ONCE " +commands.at(0);
         socket->sendSocket(&command);
-        if(socket->getPacket(&command) && !socket->getStatus())
-                QString error_string("Error: " +*socket->getErrorString());
+      //  if(socket->getPacket(&command) && !socket->getStatus())
+      //          QString error_string("Error: " +*socket->getErrorString());
+       /* QString commandString = commands.at(0);
+        std::string command;
+        command.append("SEND_ONCE " + commandString.toStdString());
+        socket->send(command); */
+
     }
     else {
         timer2->setInterval(1);
@@ -492,8 +500,14 @@ void LayoutWidget::sendIrCommandsSlot2()
     if(timer2Index < copyButton->commandChain.count()) {
          const QString command = "SEND_ONCE " +copyButton->commandChain.at(timer2Index);
             socket->sendSocket(&command);
-            if(socket->getPacket(&command) && !socket->getStatus())
-                    QString error_string("Error: " +*socket->getErrorString());
+         //   if(socket->getPacket(&command) && !socket->getStatus())
+              //      QString error_string("Error: " +*socket->getErrorString());
+
+       /* QString commandString = copyButton->commandChain.at(timer2Index);
+        std::string command;
+        command.append("SEND_ONCE " + commandString.toStdString());
+        socket->send(command);*/
+
          timer2Index++;
          timeout2 = copyButton->timeOut;
          timer2->setInterval(timeout2);
