@@ -7,6 +7,7 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, QVector<ButtonWidget*> *vector) :
     QDialog(parent),
     m_ui(new Ui::NewButtonDlg)
 {
+    buttonTextToEmit.clear();
     editMode = false;
     buttons = new QVector<ButtonWidget*>;
     buttons = vector;
@@ -23,6 +24,7 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonW
     QDialog(parent),
     m_ui(new Ui::NewButtonDlg)
 {
+    buttonTextToEmit.clear();
     editMode = true;
     buttons = new QVector<ButtonWidget*>;
     buttons = vector;
@@ -36,11 +38,9 @@ NewButtonDlg::NewButtonDlg(QWidget *parent, ButtonWidget *child, QVector<ButtonW
     m_ui->nameLineEdit->setText(QString(child->buttonText));
     int commandCount = child->commandChain.size();
     for(int i= 0;i<commandCount;i++)
-    {
         m_ui->commandChainList->insertItem(i,child->commandChain.at(i));
-    }
-    if(child->commandChain.count() > 1)
-    {
+
+    if(child->commandChain.count() > 1) {
          m_ui->horizontalScrollBar->show();
          m_ui->timeOutLabel->show();
          m_ui->timeOutValueLabel->show();
@@ -76,9 +76,9 @@ void NewButtonDlg::on_OkPushButton_clicked()
     if(editMode)
         button->timeOut = timeOut;
 
-    for(int i= 0;i<m_ui->commandChainList->count();i++) {
+    for(int i= 0;i<m_ui->commandChainList->count();i++)
         commandChain.append(m_ui->commandChainList->item(i)->text());
-    }
+
     buttonTextToEmit = m_ui->nameLineEdit->text();
     if(!editMode) {
         for(int i=0; i<buttons->count(); i++) {
@@ -106,9 +106,9 @@ void NewButtonDlg::on_OkPushButton_clicked()
                                  QMessageBox::NoButton,QMessageBox::NoButton);
       else  {
             if(!buttonNameExists) {
-                if(timeOut < 600 && commandChain.count() > 1)
-                    QMessageBox::information(this,"Time between commands!","Button usage might be unstable due the low command interval.\n 600ms or more is recommended.",
-                                         QMessageBox::NoButton,QMessageBox::NoButton);
+               // if(timeOut < 600 && commandChain.count() > 1)
+                  //  QMessageBox::information(this,"Time between commands!","Button usage might be unstable due the low command interval.\n 600ms or more is recommended.",
+                   //                      QMessageBox::NoButton,QMessageBox::NoButton);
 
                 emit addButtonToLayoutSignal(fileNameUnPressedToEmit, fileNamePressedToEmit, confFileNameToEmit, buttonTextToEmit, commandChain,0, timeOut );
                 this->close();
@@ -158,10 +158,7 @@ void NewButtonDlg::process_line(QString line)
         count = line.length();
         chars = count - 5;
         name = x.right(chars);
-        if(name.contains("blank",Qt::CaseInsensitive)) {
-            m_ui->nameLineEdit->clear();
-        }
-        else m_ui->nameLineEdit->setText(name);
+        m_ui->nameLineEdit->setText(name);
     }
 }
 
