@@ -4,16 +4,10 @@
 QtIrreco::QtIrreco(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::QtIrrecoClass)
 {
+  /*  QDir dir;
+    if(!dir.exists("/home/user/MyDocs/qtirreco"))
+         system("mkdir /home/user/MyDocs/qtirreco");
 
-
-    init = false;
-    showDatabaseButtons = false;
-    remoteNames = new QStringList();
-    lw = new LayoutWidget(this);
-
-
-
-    QDir dir;
     if(!dir.exists("/home/user/MyDocs/qtirreco/Remotes"))
          system("mkdir /home/user/MyDocs/qtirreco/Remotes");
 
@@ -21,15 +15,20 @@ QtIrreco::QtIrreco(QWidget *parent)
         system("mkdir /home/user/MyDocs/qtirreco/Devices");
 
     if(!dir.exists("/home/user/MyDocs/qtirreco/themes"))
-        dir.mkpath("/home/user/MyDocs/qtirreco/themes");
+        system("/home/user/MyDocs/qtirreco/themes"); */
 
-    remoteIndex = 0;
-    //Creates empty remotes.conf file
+     //Creates empty remotes.conf file
     QFile file(DEVICECONF);
     if (!file.open(QIODevice::ReadWrite | QIODevice::Text))
         return;
     file.close();
 
+    init = false;
+    showDatabaseButtons = false;
+    remoteNames = new QStringList();
+    lw = new LayoutWidget(this);
+
+    remoteIndex = 0;
 
     lw->show();
     lw->setFocus();
