@@ -67,29 +67,9 @@ void RemoteStartupDlg::process_line(QString line)
         }
         if(raw_flag) {
              if(line.contains("name", Qt::CaseInsensitive)) {
-                QString buttonName = line;
-
-                QString finalButtonName;
-                int lineLength;
-
-                buttonName = buttonName.trimmed();
-                lineLength = buttonName.length();
-
-                for (int i=lineLength;i>0;i--) {
-                    if(buttonName.at(i).isSpace() == true)
-                         break;
-
-                    if(buttonName.at(i).isSpace() == false)
-                         finalButtonName.append(buttonName.at(i));
-
-                }
-                int remoteLength = finalButtonName.length();
-                QString temp;
-                for(int i=1;i<remoteLength;i++)
-                    temp.prepend(finalButtonName.at(i));
-
-                finalButtonName = temp;
-                buttonNames.append(finalButtonName);
+                line = line.trimmed();
+                line.remove(0,5);
+                buttonNames.append(line);
              }
         }
         if(line.contains("begin codes", Qt::CaseInsensitive))
@@ -151,13 +131,13 @@ void RemoteStartupDlg::on_pushButton_clicked()
               name.chop(5);
               if(name == m_ui->remoteNameLineEdit->text()) {
                   sameName = true;
-                  QMessageBox::warning(this,"Remote name already exists!","Cannot create remote with the same name.",
+                  QMessageBox::warning(this,"Remote name already exists!","Cannot create remote with existing name.",
                   QMessageBox::NoButton,QMessageBox::NoButton);
               }
           }
       }
 
-    if(!sameName) {
+    if(!sameName && !m_ui->remoteNameLineEdit->text().isEmpty()) {
 
         emit lwClear();
         if(m_ui->addedButtonslistWidget->count() > 0) {
